{% extends "base.html" %} {% block main %}

## Getting started

Sketching.py offers multiple pathways depending on where you want to start coding first. Want to learn a little bit more about Sketching before you start programming? Check out our why sketching page.

### Web

We have an online editor where you can build your sketchbook without installing any software. All you need is a browser! Two examples to get you started:

- Hello World: Static
- Hello World: Interactive

Looking for more inspiration? Check out the larger examples section. We also have details on deploying your sketches to the web outside the online editor and offer a community page with chat rooms, a bug tracker, and more.

### Desktop

You can use Sketching.py locally on your own machine (like a laptop or desktop) in regular Python programs. The recommended install which enables all features (see also minimum install):

    pip install sketching[desktop]

Start with a quick hello world before learning how to make stand-alone executables or reviewing the larger examples section. Finally, check out the community page for a Discord, issue tracker, and more.

### Notebook

Jupyter ecosystem integration pairs the power of scientific programming with the expressiveness and flexibility of creative coding. Want to try it first? Check out our Binder! When you are ready to install the following recommended command enables all features (see also minimum install):

    pip install sketching[notebook]

Then, take a look at an example Jupyter Notebook, the larger examples section, and the community tab (chat, issue tracker, and more).

### Mobile

More details on mobile coming soon. Until then, try taking a look at Sketching.py's web option which is also intended to work for mobile browsers.

### Static (minimum install)

You can run Sketching.py just about anywhere you can execute Python. This includes servers which don't have desktop environments. For web, the pure Python wheel can be used (no external dependencies needed). Outside the browser, the minimum install:

    pip install sketching[minimal]

This will enable use of the Sketch2DStatic renderer built on top of Pillow. It can be used in headless environments! Need more help getting started? See the examples. Stuck? Visit the community tab to chat online with other friendly users, let developers know about problems, and more.
{% endblock %}